#
# spec file for package dleyna-core
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sover 5

Name:           dleyna-core
Version:        0.7.0
Release:        150400.1.6
Summary:        Utility functions used by higher level dLeyna libraries
License:        LGPL-2.1-only
Group:          Productivity/Multimedia/Other
URL:            https://github.com/phako/dleyna-core
Source:         %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz


BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.28
BuildRequires:  pkgconfig(glib-2.0) >= 2.28
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.28
BuildRequires:  pkgconfig(gupnp-1.2) >= 1.2.0

%description
dleyna-core is a library of utility functions that are used by the higher level dLeyna libraries that
communicate with DLNA devices, e.g., dleyna-server.

In brief, it provides APIs for logging, error, settings and task management and an IPC abstraction API.

%package -n libdleyna-core-1_0-%{_sover}
Summary:        Utility functions used by higher level dLeyna libraries
Group:          System/Libraries

%description -n libdleyna-core-1_0-%{_sover}
dleyna-core is a library of utility functions that are used by the higher level dLeyna libraries that
communicate with DLNA devices, e.g., dleyna-server.

In brief, it provides APIs for logging, error, settings and task management and an IPC abstraction API.

%package devel
Summary:        Development files for the dLeyna libraries
Group:          Development/Languages/C and C++
Requires:       libdleyna-core-1_0-%{_sover} = %{version}

%description devel
dleyna-core is a library of utility functions that are used by the higher level dLeyna libraries that
communicate with DLNA devices, e.g., dleyna-server.

In brief, it provides APIs for logging, error, settings and task management and an IPC abstraction API.

%prep
%autosetup -p1

%build
%meson \
	%{nil}
%meson_build

%install
%meson_install

%post -n libdleyna-core-1_0-%{_sover} -p /sbin/ldconfig
%postun -n libdleyna-core-1_0-%{_sover} -p /sbin/ldconfig

%files -n libdleyna-core-1_0-%{_sover}
%license COPYING
%{_libdir}/libdleyna-core-1.0.so.*

%files devel
%doc ChangeLog README.md
%{_includedir}/dleyna-1.0/
%{_libdir}/libdleyna-core-1.0.so
%{_libdir}/pkgconfig/dleyna-core-1.0.pc

%changelog
* Sun Sep 26 2021 bjorn.lie@gmail.com
- Update to version 0.7.0:
  + Port to GUPnP 1.2 API
  + Switch build system to meson
  + Make connector search path overridable by setting
    DLEYNA_CONNECTOR_PATH environment variable
  + Stability improvements for the task processor
- Add meson BuildRequires and macros, and drop libtool
  BuildRequires, following upstreams port.
- Drop dleyna-core-port-to-gupnp1_2.patch: Fixed upstream.
- Update URL and Source to new home, as intel have dropped
  maintenance of this package, go with the leading fork.
* Sun Jul  7 2019 jengelh@inai.de
- Fixup RPM category groups. Avoid em dashes in summaries.
* Thu Jun 13 2019 bjorn.lie@gmail.com
- Add dleyna-core-port-to-gupnp1_2.patch: Port to gupnp-1.2.
  Following the above patch, replace pkgconfig(gupnp-1.0) with
  pkgconfig(gupnp-1.2) BuildRequires.
* Fri Feb 16 2018 bjorn.lie@gmail.com
- Update to version 0.6.0:
  + Added new core.c and core.h to add new function
    dleyna_core_prv_conve.
  + [m4]:
  - Don't use bash "let" builtin.
  - Use AS_VAR_APPEND macro instead of "+=".
  + Don't schedule dleyna_task_processor_t->on_quit_cb more than
    once.
  + Remove all queues before dleyna_task_processor_t->on_quit_cb is
    run.
  + Gracefully exit in case of dbus session crash.
- Add libtool BuildRequires and pass autoreconf, bootstrap tarball.
- Do a minor spec cleanup.
- Rename libdleyna-core-1_0-4 subpackage to libdleyna-core-1_0-5,
  following upstreams soname bump. Do this via adding a sover
  define, currently set to 5.
- Pass --disable-static to configure, ensure we do not build any
  static files.
* Sat May  2 2015 zaitor@opensuse.org
- Update to version 0.5.0:
  + [m4] Don't use bash arrays in m4 macros.
  + [Autoconf] Add --no-undefined to compiler option.
  + [settings]:
  - Add "push-host-port" setting.
  - Add "port" setting.
  + [Warnings] Fix compile warnings on ARM.
- Rename subpackage libdleyna-core-1_0-4 following upstreams soname
  bump.
* Mon Aug 25 2014 dimstar@opensuse.org
- Update to version 0.4.0:
  + Minor bug fixes.
- Rename libdleyna-core-1_0-1 subpackage to libdleyna-core-1_0-3,
  following upstreams soname bump.
* Mon Aug 12 2013 dimstar@opensuse.org
- Initial package, version 0.1.0.
